@@ -5,6 +5,7 @@
 */
 
 #include "downloader.h"
+#include <kio/transferjob.h>
 
 #include <cstdlib>
 #include <cstring>
@@ -12,7 +13,6 @@
 #include <QTextCodec>
 
 #include <KLocalizedString>
-#include <kio/job.h>
 
 namespace KPAC
 {
@@ -28,17 +28,14 @@ void Downloader::download(const QUrl &url)
     m_scriptURL = url;
 
     KIO::TransferJob *job = KIO::get(url, KIO::NoReload, KIO::HideProgressInfo);
-    connect(job, &KIO::TransferJob::data,
-            this, &Downloader::data);
-    connect(job, &KIO::TransferJob::redirection,
-            this, &Downloader::redirection);
-    connect(job, &KJob::result,
-            this, QOverload<KJob*>::of(&Downloader::result));
+    connect(job, &KIO::TransferJob::data, this, &Downloader::data);
+    connect(job, &KIO::TransferJob::redirection, this, &Downloader::redirection);
+    connect(job, &KJob::result, this, qOverload<KJob *>(&Downloader::result));
 }
 
 void Downloader::failed()
 {
-    emit result(false);
+    Q_EMIT result(false);
 }
 
 void Downloader::setError(const QString &error)
@@ -74,16 +71,14 @@ void Downloader::result(KJob *job)
             Q_ASSERT(codec);
         }
         m_script = codec->toUnicode(m_data);
-        emit result(true);
+        Q_EMIT result(true);
     } else {
-        if (job->error())
-            setError(i18n("Could not download the proxy configuration script:\n%1",
-                          job->errorString()));
-        else {
-            setError(i18n("Could not download the proxy configuration script"));    // error page
+        if (job->error()) {
+            setError(i18n("Could not download the proxy configuration script:\n%1", job->errorString()));
+        } else {
+            setError(i18n("Could not download the proxy configuration script")); // error page
         }
         failed();
     }
 }
 }
-
