@@ -283,7 +283,7 @@ bool KIO::JobUiDelegate::askDeleteConfirmation(const QList<QUrl> &urls, Deletion
                            "cannot be undone.</emphasis>",
                            prettyList.first()),
                     i18n("Delete Permanently"),
-                    KStandardGuiItem::del(),
+                    KGuiItem(i18nc("@action:button", "Delete Permanently"), QStringLiteral("edit-delete")),
                     KStandardGuiItem::cancel(),
                     keyName,
                     options);
@@ -297,7 +297,7 @@ bool KIO::JobUiDelegate::askDeleteConfirmation(const QList<QUrl> &urls, Deletion
                         prettyList.count()),
                     prettyList,
                     i18n("Delete Permanently"),
-                    KStandardGuiItem::del(),
+                    KGuiItem(i18nc("@action:button", "Delete Permanently"), QStringLiteral("edit-delete")),
                     KStandardGuiItem::cancel(),
                     keyName,
                     options);
@@ -357,10 +357,10 @@ bool KIO::JobUiDelegate::askDeleteConfirmation(const QList<QUrl> &urls, Deletion
 int KIO::JobUiDelegate::requestMessageBox(KIO::JobUiDelegate::MessageBoxType type,
                                           const QString &text,
                                           const QString &title,
-                                          const QString &buttonYes,
-                                          const QString &buttonNo,
-                                          const QString &iconYes,
-                                          const QString &iconNo,
+                                          const QString &primaryActionText,
+                                          const QString &secondaryActionText,
+                                          const QString &primaryActionIconName,
+                                          const QString &secondaryActionIconName,
                                           const QString &dontAskAgainName,
                                           const KIO::MetaData &metaData)
 {
@@ -371,36 +371,58 @@ int KIO::JobUiDelegate::requestMessageBox(KIO::JobUiDelegate::MessageBoxType typ
     KConfig config(QStringLiteral("kioslaverc"));
     KMessageBox::setDontShowAgainConfig(&config);
 
-    KGuiItem buttonYesGui = KStandardGuiItem::yes();
-    if (!buttonYes.isEmpty()) {
-        buttonYesGui.setText(buttonYes);
+#if KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(5, 100)
+    QT_WARNING_PUSH
+    QT_WARNING_DISABLE_DEPRECATED
+    KGuiItem primaryActionTextGui = KStandardGuiItem::yes();
+    KGuiItem secondaryActionTextGui = KStandardGuiItem::no();
+    QT_WARNING_POP
+
+    if (!primaryActionText.isEmpty()) {
+        primaryActionTextGui.setText(primaryActionText);
     }
-    if (!iconYes.isNull()) {
-        buttonYesGui.setIconName(iconYes);
+    if (!primaryActionIconName.isNull()) {
+        primaryActionTextGui.setIconName(primaryActionIconName);
     }
 
-    KGuiItem buttonNoGui = KStandardGuiItem::no();
-    if (!buttonNo.isEmpty()) {
-        buttonNoGui.setText(buttonNo);
+    if (!secondaryActionText.isEmpty()) {
+        secondaryActionTextGui.setText(secondaryActionText);
     }
-    if (!iconNo.isNull()) {
-        buttonNoGui.setIconName(iconNo);
+    if (!secondaryActionIconName.isNull()) {
+        secondaryActionTextGui.setIconName(secondaryActionIconName);
     }
+#else
+    KGuiItem primaryActionTextGui(primaryActionText, primaryActionIconName);
+    KGuiItem secondaryActionTextGui(secondaryActionText, secondaryActionIconName);
+#endif
 
     KMessageBox::Options options(KMessageBox::Notify | KMessageBox::WindowModal);
 
     switch (type) {
-    case QuestionYesNo:
-        result = KMessageBox::questionYesNo(window(), text, title, buttonYesGui, buttonNoGui, dontAskAgainName, options);
+    case QuestionTwoActions:
+        result = KMessageBox::questionTwoActions(window(), text, title, primaryActionTextGui, secondaryActionTextGui, dontAskAgainName, options);
         break;
-    case WarningYesNo:
-        result = KMessageBox::warningYesNo(window(), text, title, buttonYesGui, buttonNoGui, dontAskAgainName, options | KMessageBox::Dangerous);
+    case WarningTwoActions:
+        result = KMessageBox::warningTwoActions(window(),
+                                                text,
+                                                title,
+                                                primaryActionTextGui,
+                                                secondaryActionTextGui,
+                                                dontAskAgainName,
+                                                options | KMessageBox::Dangerous);
         break;
-    case WarningYesNoCancel:
-        result = KMessageBox::warningYesNoCancel(window(), text, title, buttonYesGui, buttonNoGui, KStandardGuiItem::cancel(), dontAskAgainName, options);
+    case WarningTwoActionsCancel:
+        result = KMessageBox::warningTwoActionsCancel(window(),
+                                                      text,
+                                                      title,
+                                                      primaryActionTextGui,
+                                                      secondaryActionTextGui,
+                                                      KStandardGuiItem::cancel(),
+                                                      dontAskAgainName,
+                                                      options);
         break;
     case WarningContinueCancel:
-        result = KMessageBox::warningContinueCancel(window(), text, title, buttonYesGui, KStandardGuiItem::cancel(), dontAskAgainName, options);
+        result = KMessageBox::warningContinueCancel(window(), text, title, primaryActionTextGui, KStandardGuiItem::cancel(), dontAskAgainName, options);
         break;
     case Information:
         KMessageBox::information(window(), text, title, dontAskAgainName, options);
@@ -408,7 +430,7 @@ int KIO::JobUiDelegate::requestMessageBox(KIO::JobUiDelegate::MessageBoxType typ
         break;
     case SSLMessageBox: {
         QPointer<KSslInfoDialog> kid(new KSslInfoDialog(window()));
-        //### this is boilerplate code and appears in khtml_part.cpp almost unchanged!
+        // ### this is boilerplate code and appears in khtml_part.cpp almost unchanged!
         const QStringList sl = metaData.value(QStringLiteral("ssl_peer_chain")).split(QLatin1Char('\x01'), Qt::SkipEmptyParts);
         QList<QSslCertificate> certChain;
         bool decodedOk = true;
